"""
    Fastly API

    Via the Fastly API you can perform any of the operations that are possible within the management console,  including creating services, domains, and backends, configuring rules or uploading your own application code, as well as account operations such as user administration and billing reports. The API is organized into collections of endpoints that allow manipulation of objects related to Fastly services and accounts. For the most accurate and up-to-date API reference content, visit our [Developer Hub](https://developer.fastly.com/reference/api/)   # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: oss@fastly.com
"""


import re  # noqa: F401
import sys  # noqa: F401

from fastly.api_client import ApiClient, Endpoint as _Endpoint
from fastly.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)


class LegacyWafRuleStatusApi(object):
    """NOTE: This class is auto generated.
    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.get_waf_firewall_rule_status_endpoint = _Endpoint(
            settings={
                'response_type': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/service/{service_id}/wafs/{firewall_id}/rules/{waf_rule_id}/rule_status',
                'operation_id': 'get_waf_firewall_rule_status',
                'http_method': 'GET',
                'servers': [
                    {
                        'url': "https://api.fastly.com",
                        'description': "No description provided",
                    },
                ]
            },
            params_map={
                'all': [
                    'service_id',
                    'firewall_id',
                    'waf_rule_id',
                ],
                'required': [
                    'service_id',
                    'firewall_id',
                    'waf_rule_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'service_id':
                        (str,),
                    'firewall_id':
                        (str,),
                    'waf_rule_id':
                        (str,),
                },
                'attribute_map': {
                    'service_id': 'service_id',
                    'firewall_id': 'firewall_id',
                    'waf_rule_id': 'waf_rule_id',
                },
                'location_map': {
                    'service_id': 'path',
                    'firewall_id': 'path',
                    'waf_rule_id': 'path',
                },
                'path_params_allow_reserved_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/vnd.api+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.list_waf_firewall_rule_statuses_endpoint = _Endpoint(
            settings={
                'response_type': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/service/{service_id}/wafs/{firewall_id}/rule_statuses',
                'operation_id': 'list_waf_firewall_rule_statuses',
                'http_method': 'GET',
                'servers': [
                    {
                        'url': "https://api.fastly.com",
                        'description': "No description provided",
                    },
                ]
            },
            params_map={
                'all': [
                    'service_id',
                    'firewall_id',
                    'filter_status',
                    'filter_rule_message',
                    'filter_rule_rule_id',
                    'filter_rule_tags',
                    'filter_rule_tags_name',
                    'include',
                    'page_number',
                    'page_size',
                ],
                'required': [
                    'service_id',
                    'firewall_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'page_size',
                ]
            },
            root_map={
                'validations': {
                    ('page_size',): {

                        'inclusive_maximum': 100,
                        'inclusive_minimum': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'service_id':
                        (str,),
                    'firewall_id':
                        (str,),
                    'filter_status':
                        (str,),
                    'filter_rule_message':
                        (str,),
                    'filter_rule_rule_id':
                        (str,),
                    'filter_rule_tags':
                        (str,),
                    'filter_rule_tags_name':
                        (str,),
                    'include':
                        (str,),
                    'page_number':
                        (int,),
                    'page_size':
                        (int,),
                },
                'attribute_map': {
                    'service_id': 'service_id',
                    'firewall_id': 'firewall_id',
                    'filter_status': 'filter[status]',
                    'filter_rule_message': 'filter[rule][message]',
                    'filter_rule_rule_id': 'filter[rule][rule_id]',
                    'filter_rule_tags': 'filter[rule][tags]',
                    'filter_rule_tags_name': 'filter[rule][tags][name]',
                    'include': 'include',
                    'page_number': 'page[number]',
                    'page_size': 'page[size]',
                },
                'location_map': {
                    'service_id': 'path',
                    'firewall_id': 'path',
                    'filter_status': 'query',
                    'filter_rule_message': 'query',
                    'filter_rule_rule_id': 'query',
                    'filter_rule_tags': 'query',
                    'filter_rule_tags_name': 'query',
                    'include': 'query',
                    'page_number': 'query',
                    'page_size': 'query',
                },
                'path_params_allow_reserved_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/vnd.api+json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.update_waf_firewall_rule_status_endpoint = _Endpoint(
            settings={
                'response_type': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/service/{service_id}/wafs/{firewall_id}/rules/{waf_rule_id}/rule_status',
                'operation_id': 'update_waf_firewall_rule_status',
                'http_method': 'PATCH',
                'servers': [
                    {
                        'url': "https://api.fastly.com",
                        'description': "No description provided",
                    },
                ]
            },
            params_map={
                'all': [
                    'service_id',
                    'firewall_id',
                    'waf_rule_id',
                    'request_body',
                ],
                'required': [
                    'service_id',
                    'firewall_id',
                    'waf_rule_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'service_id':
                        (str,),
                    'firewall_id':
                        (str,),
                    'waf_rule_id':
                        (str,),
                    'request_body':
                        ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                },
                'attribute_map': {
                    'service_id': 'service_id',
                    'firewall_id': 'firewall_id',
                    'waf_rule_id': 'waf_rule_id',
                },
                'location_map': {
                    'service_id': 'path',
                    'firewall_id': 'path',
                    'waf_rule_id': 'path',
                    'request_body': 'body',
                },
                'path_params_allow_reserved_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/vnd.api+json'
                ],
                'content_type': [
                    'application/vnd.api+json'
                ]
            },
            api_client=api_client
        )
        self.update_waf_firewall_rule_statuses_tag_endpoint = _Endpoint(
            settings={
                'response_type': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/service/{service_id}/wafs/{firewall_id}/rule_statuses',
                'operation_id': 'update_waf_firewall_rule_statuses_tag',
                'http_method': 'POST',
                'servers': [
                    {
                        'url': "https://api.fastly.com",
                        'description': "No description provided",
                    },
                ]
            },
            params_map={
                'all': [
                    'service_id',
                    'firewall_id',
                    'name',
                    'force',
                    'request_body',
                ],
                'required': [
                    'service_id',
                    'firewall_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'service_id':
                        (str,),
                    'firewall_id':
                        (str,),
                    'name':
                        (str,),
                    'force':
                        (str,),
                    'request_body':
                        ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                },
                'attribute_map': {
                    'service_id': 'service_id',
                    'firewall_id': 'firewall_id',
                    'name': 'name',
                    'force': 'force',
                },
                'location_map': {
                    'service_id': 'path',
                    'firewall_id': 'path',
                    'name': 'query',
                    'force': 'query',
                    'request_body': 'body',
                },
                'path_params_allow_reserved_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/vnd.api+json'
                ],
                'content_type': [
                    'application/vnd.api+json'
                ]
            },
            api_client=api_client
        )

    def get_waf_firewall_rule_status(
        self,
        service_id,
        firewall_id,
        waf_rule_id,
        **kwargs
    ):
        """Get the status of a rule on a firewall  # noqa: E501

        Get a specific rule status object for a particular service, firewall, and rule.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_waf_firewall_rule_status(service_id, firewall_id, waf_rule_id, async_req=True)
        >>> result = thread.get()

        Args:
            service_id (str): Alphanumeric string identifying the service.
            firewall_id (str): Alphanumeric string identifying a Firewall.
            waf_rule_id (str): Alphanumeric string identifying a WAF rule.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['service_id'] = \
            service_id
        kwargs['firewall_id'] = \
            firewall_id
        kwargs['waf_rule_id'] = \
            waf_rule_id
        return self.get_waf_firewall_rule_status_endpoint.call_with_http_info(**kwargs)

    def list_waf_firewall_rule_statuses(
        self,
        service_id,
        firewall_id,
        **kwargs
    ):
        """List rule statuses  # noqa: E501

        List all rule statuses for a particular service and firewall.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_waf_firewall_rule_statuses(service_id, firewall_id, async_req=True)
        >>> result = thread.get()

        Args:
            service_id (str): Alphanumeric string identifying the service.
            firewall_id (str): Alphanumeric string identifying a Firewall.

        Keyword Args:
            filter_status (str): Limit results to rule statuses with the specified status.. [optional]
            filter_rule_message (str): Limit results to rule statuses whose rules have the specified message.. [optional]
            filter_rule_rule_id (str): Limit results to rule statuses whose rules represent the specified ModSecurity rule_id.. [optional]
            filter_rule_tags (str): Limit results to rule statuses whose rules relate to the specified tag IDs.. [optional]
            filter_rule_tags_name (str): Limit results to rule statuses whose rules related to the named tags.. [optional]
            include (str): Include relationships. Optional, comma separated values. Permitted values: `tags`. . [optional]
            page_number (int): Current page.. [optional]
            page_size (int): Number of records per page.. [optional] if omitted the server will use the default value of 20
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['service_id'] = \
            service_id
        kwargs['firewall_id'] = \
            firewall_id
        return self.list_waf_firewall_rule_statuses_endpoint.call_with_http_info(**kwargs)

    def update_waf_firewall_rule_status(
        self,
        service_id,
        firewall_id,
        waf_rule_id,
        **kwargs
    ):
        """Update the status of a rule  # noqa: E501

        Update a rule status for a particular service, firewall, and rule.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_waf_firewall_rule_status(service_id, firewall_id, waf_rule_id, async_req=True)
        >>> result = thread.get()

        Args:
            service_id (str): Alphanumeric string identifying the service.
            firewall_id (str): Alphanumeric string identifying a Firewall.
            waf_rule_id (str): Alphanumeric string identifying a WAF rule.

        Keyword Args:
            request_body ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['service_id'] = \
            service_id
        kwargs['firewall_id'] = \
            firewall_id
        kwargs['waf_rule_id'] = \
            waf_rule_id
        return self.update_waf_firewall_rule_status_endpoint.call_with_http_info(**kwargs)

    def update_waf_firewall_rule_statuses_tag(
        self,
        service_id,
        firewall_id,
        **kwargs
    ):
        """Create or update status of a tagged group of rules  # noqa: E501

        Create or update all rule statuses for a particular service and firewall, based on tag name. By default, only rule status for enabled rules (with status log or block) will be updated. To update rule statuses for disabled rules under the specified tag, use the force attribute.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_waf_firewall_rule_statuses_tag(service_id, firewall_id, async_req=True)
        >>> result = thread.get()

        Args:
            service_id (str): Alphanumeric string identifying the service.
            firewall_id (str): Alphanumeric string identifying a Firewall.

        Keyword Args:
            name (str): The tag name to use to determine the set of rules to update. For example, OWASP or language-php.. [optional]
            force (str): Whether or not to update rule statuses for disabled rules. Optional.. [optional]
            request_body ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['service_id'] = \
            service_id
        kwargs['firewall_id'] = \
            firewall_id
        return self.update_waf_firewall_rule_statuses_tag_endpoint.call_with_http_info(**kwargs)




"""
    Fastly API

    Via the Fastly API you can perform any of the operations that are possible within the management console,  including creating services, domains, and backends, configuring rules or uploading your own application code, as well as account operations such as user administration and billing reports. The API is organized into collections of endpoints that allow manipulation of objects related to Fastly services and accounts. For the most accurate and up-to-date API reference content, visit our [Developer Hub](https://developer.fastly.com/reference/api/)   # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: oss@fastly.com
"""


import re  # noqa: F401
import sys  # noqa: F401

from fastly.api_client import ApiClient, Endpoint as _Endpoint
from fastly.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from fastly.model.historical_domains_response import HistoricalDomainsResponse


class DomainInspectorHistoricalApi(object):
    """NOTE: This class is auto generated.
    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.get_domain_inspector_historical_endpoint = _Endpoint(
            settings={
                'response_type': (HistoricalDomainsResponse,),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/metrics/domains/services/{service_id}',
                'operation_id': 'get_domain_inspector_historical',
                'http_method': 'GET',
                'servers': [
                    {
                        'url': "https://api.fastly.com",
                        'description': "No description provided",
                    },
                ]
            },
            params_map={
                'all': [
                    'service_id',
                    'start',
                    'end',
                    'downsample',
                    'metric',
                    'group_by',
                    'limit',
                    'cursor',
                    'region',
                    'datacenter',
                    'domain',
                ],
                'required': [
                    'service_id',
                ],
                'nullable': [
                ],
                'enum': [
                    'downsample',
                    'group_by',
                    'region',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('downsample',): {

                        "HOUR": "hour",
                        "MINUTE": "minute",
                        "DAY": "day"
                    },
                    ('group_by',): {

                        "DOMAIN": "domain",
                        "DATACENTER": "datacenter",
                        "REGION": "region",
                        "NONE": "none"
                    },
                    ('region',): {

                        "USA": "usa",
                        "EUROPE": "europe",
                        "ASIA": "asia",
                        "ASIA_INDIA": "asia_india",
                        "ASIA_SOUTHKOREA": "asia_southkorea",
                        "AFRICA_STD": "africa_std",
                        "SOUTHAMERICA_STD": "southamerica_std"
                    },
                },
                'openapi_types': {
                    'service_id':
                        (str,),
                    'start':
                        (str,),
                    'end':
                        (str,),
                    'downsample':
                        (str,),
                    'metric':
                        (str,),
                    'group_by':
                        (str,),
                    'limit':
                        (str,),
                    'cursor':
                        (str,),
                    'region':
                        (str,),
                    'datacenter':
                        (str,),
                    'domain':
                        (str,),
                },
                'attribute_map': {
                    'service_id': 'service_id',
                    'start': 'start',
                    'end': 'end',
                    'downsample': 'downsample',
                    'metric': 'metric',
                    'group_by': 'group_by',
                    'limit': 'limit',
                    'cursor': 'cursor',
                    'region': 'region',
                    'datacenter': 'datacenter',
                    'domain': 'domain',
                },
                'location_map': {
                    'service_id': 'path',
                    'start': 'query',
                    'end': 'query',
                    'downsample': 'query',
                    'metric': 'query',
                    'group_by': 'query',
                    'limit': 'query',
                    'cursor': 'query',
                    'region': 'query',
                    'datacenter': 'query',
                    'domain': 'query',
                },
                'path_params_allow_reserved_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def get_domain_inspector_historical(
        self,
        service_id,
        **kwargs
    ):
        """Get historical domain data for a service  # noqa: E501

        Fetches historical domain metrics for a given Fastly service, optionally filtering and grouping the results by domain, region, or POP.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_domain_inspector_historical(service_id, async_req=True)
        >>> result = thread.get()

        Args:
            service_id (str): Alphanumeric string identifying the service.

        Keyword Args:
            start (str): A valid ISO-8601-formatted date and time, or UNIX timestamp, indicating the inclusive start of the query time range. If not provided, a default is chosen based on the provided `downsample` value.. [optional]
            end (str): A valid ISO-8601-formatted date and time, or UNIX timestamp, indicating the exclusive end of the query time range. If not provided, a default is chosen based on the provided `downsample` value.. [optional]
            downsample (str): Duration of sample windows.. [optional] if omitted the server will use the default value of "hour"
            metric (str): The metrics to retrieve. Multiple values should be comma-separated.. [optional] if omitted the server will use the default value of "edge_requests"
            group_by (str): Dimensions to return in the query. Multiple dimensions may be separated by commas. For example, `group_by=domain` will return one timeseries for every domain, as a total across all datacenters (POPs). . [optional]
            limit (str): Number of results per page. The maximum is 200.. [optional] if omitted the server will use the default value of "100"
            cursor (str): Cursor value from the `next_cursor` field of a previous response, used to retrieve the next page. To request the first page, this should be empty.. [optional]
            region (str): Limit query to one or more specific geographic regions. Values should be comma-separated. . [optional]
            datacenter (str): Limit query to one or more specific POPs. Values should be comma-separated.. [optional]
            domain (str): Limit query to one or more specific domains. Values should be comma-separated.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            HistoricalDomainsResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['service_id'] = \
            service_id
        return self.get_domain_inspector_historical_endpoint.call_with_http_info(**kwargs)




"""
    Fastly API

    Via the Fastly API you can perform any of the operations that are possible within the management console,  including creating services, domains, and backends, configuring rules or uploading your own application code, as well as account operations such as user administration and billing reports. The API is organized into collections of endpoints that allow manipulation of objects related to Fastly services and accounts. For the most accurate and up-to-date API reference content, visit our [Developer Hub](https://developer.fastly.com/reference/api/)   # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: oss@fastly.com
"""


import re  # noqa: F401
import sys  # noqa: F401

from fastly.api_client import ApiClient, Endpoint as _Endpoint
from fastly.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from fastly.model.inline_response200 import InlineResponse200
from fastly.model.rate_limiter_response import RateLimiterResponse


class RateLimiterApi(object):
    """NOTE: This class is auto generated.
    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.create_rate_limiter_endpoint = _Endpoint(
            settings={
                'response_type': (RateLimiterResponse,),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/service/{service_id}/version/{version_id}/rate-limiters',
                'operation_id': 'create_rate_limiter',
                'http_method': 'POST',
                'servers': [
                    {
                        'url': "https://api.fastly.com",
                        'description': "No description provided",
                    },
                ]
            },
            params_map={
                'all': [
                    'service_id',
                    'version_id',
                    'name',
                    'uri_dictionary_name',
                    'http_methods',
                    'rps_limit',
                    'window_size',
                    'client_key',
                    'penalty_box_duration',
                    'action',
                    'response_object_name',
                    'logger_type',
                    'feature_revision',
                ],
                'required': [
                    'service_id',
                    'version_id',
                ],
                'nullable': [
                    'uri_dictionary_name',
                    'response_object_name',
                ],
                'enum': [
                    'http_methods',
                    'window_size',
                    'action',
                    'logger_type',
                ],
                'validation': [
                    'name',
                    'uri_dictionary_name',
                    'http_methods',
                    'rps_limit',
                    'client_key',
                    'penalty_box_duration',
                    'action',
                    'response_object_name',
                ]
            },
            root_map={
                'validations': {
                    ('name',): {
                        'max_length': 255,
                        'min_length': 1,
                    },
                    ('uri_dictionary_name',): {
                        'max_length': 255,
                        'min_length': 1,
                    },
                    ('http_methods',): {

                        'min_items': 1,
                    },
                    ('rps_limit',): {

                        'inclusive_maximum': 10000,
                        'inclusive_minimum': 10,
                    },
                    ('client_key',): {

                        'min_items': 1,
                    },
                    ('penalty_box_duration',): {

                        'inclusive_maximum': 60,
                        'inclusive_minimum': 1,
                    },
                    ('action',): {

                        'min_length': 1,
                    },
                    ('response_object_name',): {
                        'max_length': 255,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('http_methods',): {

                        "HEAD": "HEAD",
                        "OPTIONS": "OPTIONS",
                        "GET": "GET",
                        "POST": "POST",
                        "PUT": "PUT",
                        "PATCH": "PATCH",
                        "DELETE": "DELETE",
                        "TRACE": "TRACE"
                    },
                    ('window_size',): {

                        "one_second": 1,
                        "ten_seconds": 10,
                        "one_minute": 60
                    },
                    ('action',): {

                        "RESPONSE": "response",
                        "RESPONSE_OBJECT": "response_object",
                        "LOG_ONLY": "log_only"
                    },
                    ('logger_type',): {

                        "AZUREBLOB": "azureblob",
                        "BIGQUERY": "bigquery",
                        "CLOUDFILES": "cloudfiles",
                        "DATADOG": "datadog",
                        "DIGITALOCEAN": "digitalocean",
                        "ELASTICSEARCH": "elasticsearch",
                        "FTP": "ftp",
                        "GCS": "gcs",
                        "GOOGLEANALYTICS": "googleanalytics",
                        "HEROKU": "heroku",
                        "HONEYCOMB": "honeycomb",
                        "HTTP": "http",
                        "HTTPS": "https",
                        "KAFKA": "kafka",
                        "KINESIS": "kinesis",
                        "LOGENTRIES": "logentries",
                        "LOGGLY": "loggly",
                        "LOGSHUTTLE": "logshuttle",
                        "NEWRELIC": "newrelic",
                        "NEWRELICOTLP": "newrelicotlp",
                        "OPENSTACK": "openstack",
                        "PAPERTRAIL": "papertrail",
                        "PUBSUB": "pubsub",
                        "S3": "s3",
                        "SCALYR": "scalyr",
                        "SFTP": "sftp",
                        "SPLUNK": "splunk",
                        "STACKDRIVER": "stackdriver",
                        "SUMOLOGIC": "sumologic",
                        "SYSLOG": "syslog"
                    },
                },
                'openapi_types': {
                    'service_id':
                        (str,),
                    'version_id':
                        (int,),
                    'name':
                        (str,),
                    'uri_dictionary_name':
                        (str, none_type,),
                    'http_methods':
                        ([str],),
                    'rps_limit':
                        (int,),
                    'window_size':
                        (int,),
                    'client_key':
                        ([str],),
                    'penalty_box_duration':
                        (int,),
                    'action':
                        (str,),
                    'response_object_name':
                        (str, none_type,),
                    'logger_type':
                        (str,),
                    'feature_revision':
                        (int,),
                },
                'attribute_map': {
                    'service_id': 'service_id',
                    'version_id': 'version_id',
                    'name': 'name',
                    'uri_dictionary_name': 'uri_dictionary_name',
                    'http_methods': 'http_methods',
                    'rps_limit': 'rps_limit',
                    'window_size': 'window_size',
                    'client_key': 'client_key',
                    'penalty_box_duration': 'penalty_box_duration',
                    'action': 'action',
                    'response_object_name': 'response_object_name',
                    'logger_type': 'logger_type',
                    'feature_revision': 'feature_revision',
                },
                'location_map': {
                    'service_id': 'path',
                    'version_id': 'path',
                    'name': 'form',
                    'uri_dictionary_name': 'form',
                    'http_methods': 'form',
                    'rps_limit': 'form',
                    'window_size': 'form',
                    'client_key': 'form',
                    'penalty_box_duration': 'form',
                    'action': 'form',
                    'response_object_name': 'form',
                    'logger_type': 'form',
                    'feature_revision': 'form',
                },
                'path_params_allow_reserved_map': {
                },
                'collection_format_map': {
                    'http_methods': 'csv',
                    'client_key': 'csv',
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/x-www-form-urlencoded'
                ]
            },
            api_client=api_client
        )
        self.delete_rate_limiter_endpoint = _Endpoint(
            settings={
                'response_type': (InlineResponse200,),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/rate-limiters/{rate_limiter_id}',
                'operation_id': 'delete_rate_limiter',
                'http_method': 'DELETE',
                'servers': [
                    {
                        'url': "https://api.fastly.com",
                        'description': "No description provided",
                    },
                ]
            },
            params_map={
                'all': [
                    'rate_limiter_id',
                ],
                'required': [
                    'rate_limiter_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'rate_limiter_id':
                        (str,),
                },
                'attribute_map': {
                    'rate_limiter_id': 'rate_limiter_id',
                },
                'location_map': {
                    'rate_limiter_id': 'path',
                },
                'path_params_allow_reserved_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_rate_limiter_endpoint = _Endpoint(
            settings={
                'response_type': (RateLimiterResponse,),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/rate-limiters/{rate_limiter_id}',
                'operation_id': 'get_rate_limiter',
                'http_method': 'GET',
                'servers': [
                    {
                        'url': "https://api.fastly.com",
                        'description': "No description provided",
                    },
                ]
            },
            params_map={
                'all': [
                    'rate_limiter_id',
                ],
                'required': [
                    'rate_limiter_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'rate_limiter_id':
                        (str,),
                },
                'attribute_map': {
                    'rate_limiter_id': 'rate_limiter_id',
                },
                'location_map': {
                    'rate_limiter_id': 'path',
                },
                'path_params_allow_reserved_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.list_rate_limiters_endpoint = _Endpoint(
            settings={
                'response_type': ([RateLimiterResponse],),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/service/{service_id}/version/{version_id}/rate-limiters',
                'operation_id': 'list_rate_limiters',
                'http_method': 'GET',
                'servers': [
                    {
                        'url': "https://api.fastly.com",
                        'description': "No description provided",
                    },
                ]
            },
            params_map={
                'all': [
                    'service_id',
                    'version_id',
                ],
                'required': [
                    'service_id',
                    'version_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'service_id':
                        (str,),
                    'version_id':
                        (int,),
                },
                'attribute_map': {
                    'service_id': 'service_id',
                    'version_id': 'version_id',
                },
                'location_map': {
                    'service_id': 'path',
                    'version_id': 'path',
                },
                'path_params_allow_reserved_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.update_rate_limiter_endpoint = _Endpoint(
            settings={
                'response_type': (RateLimiterResponse,),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/rate-limiters/{rate_limiter_id}',
                'operation_id': 'update_rate_limiter',
                'http_method': 'PUT',
                'servers': [
                    {
                        'url': "https://api.fastly.com",
                        'description': "No description provided",
                    },
                ]
            },
            params_map={
                'all': [
                    'rate_limiter_id',
                    'name',
                    'uri_dictionary_name',
                    'http_methods',
                    'rps_limit',
                    'window_size',
                    'client_key',
                    'penalty_box_duration',
                    'action',
                    'response_object_name',
                    'logger_type',
                    'feature_revision',
                ],
                'required': [
                    'rate_limiter_id',
                ],
                'nullable': [
                    'uri_dictionary_name',
                    'response_object_name',
                ],
                'enum': [
                    'http_methods',
                    'window_size',
                    'action',
                    'logger_type',
                ],
                'validation': [
                    'name',
                    'uri_dictionary_name',
                    'http_methods',
                    'rps_limit',
                    'client_key',
                    'penalty_box_duration',
                    'action',
                    'response_object_name',
                ]
            },
            root_map={
                'validations': {
                    ('name',): {
                        'max_length': 255,
                        'min_length': 1,
                    },
                    ('uri_dictionary_name',): {
                        'max_length': 255,
                        'min_length': 1,
                    },
                    ('http_methods',): {

                        'min_items': 1,
                    },
                    ('rps_limit',): {

                        'inclusive_maximum': 10000,
                        'inclusive_minimum': 10,
                    },
                    ('client_key',): {

                        'min_items': 1,
                    },
                    ('penalty_box_duration',): {

                        'inclusive_maximum': 60,
                        'inclusive_minimum': 1,
                    },
                    ('action',): {

                        'min_length': 1,
                    },
                    ('response_object_name',): {
                        'max_length': 255,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('http_methods',): {

                        "HEAD": "HEAD",
                        "OPTIONS": "OPTIONS",
                        "GET": "GET",
                        "POST": "POST",
                        "PUT": "PUT",
                        "PATCH": "PATCH",
                        "DELETE": "DELETE",
                        "TRACE": "TRACE"
                    },
                    ('window_size',): {

                        "one_second": 1,
                        "ten_seconds": 10,
                        "one_minute": 60
                    },
                    ('action',): {

                        "RESPONSE": "response",
                        "RESPONSE_OBJECT": "response_object",
                        "LOG_ONLY": "log_only"
                    },
                    ('logger_type',): {

                        "AZUREBLOB": "azureblob",
                        "BIGQUERY": "bigquery",
                        "CLOUDFILES": "cloudfiles",
                        "DATADOG": "datadog",
                        "DIGITALOCEAN": "digitalocean",
                        "ELASTICSEARCH": "elasticsearch",
                        "FTP": "ftp",
                        "GCS": "gcs",
                        "GOOGLEANALYTICS": "googleanalytics",
                        "HEROKU": "heroku",
                        "HONEYCOMB": "honeycomb",
                        "HTTP": "http",
                        "HTTPS": "https",
                        "KAFKA": "kafka",
                        "KINESIS": "kinesis",
                        "LOGENTRIES": "logentries",
                        "LOGGLY": "loggly",
                        "LOGSHUTTLE": "logshuttle",
                        "NEWRELIC": "newrelic",
                        "NEWRELICOTLP": "newrelicotlp",
                        "OPENSTACK": "openstack",
                        "PAPERTRAIL": "papertrail",
                        "PUBSUB": "pubsub",
                        "S3": "s3",
                        "SCALYR": "scalyr",
                        "SFTP": "sftp",
                        "SPLUNK": "splunk",
                        "STACKDRIVER": "stackdriver",
                        "SUMOLOGIC": "sumologic",
                        "SYSLOG": "syslog"
                    },
                },
                'openapi_types': {
                    'rate_limiter_id':
                        (str,),
                    'name':
                        (str,),
                    'uri_dictionary_name':
                        (str, none_type,),
                    'http_methods':
                        ([str],),
                    'rps_limit':
                        (int,),
                    'window_size':
                        (int,),
                    'client_key':
                        ([str],),
                    'penalty_box_duration':
                        (int,),
                    'action':
                        (str,),
                    'response_object_name':
                        (str, none_type,),
                    'logger_type':
                        (str,),
                    'feature_revision':
                        (int,),
                },
                'attribute_map': {
                    'rate_limiter_id': 'rate_limiter_id',
                    'name': 'name',
                    'uri_dictionary_name': 'uri_dictionary_name',
                    'http_methods': 'http_methods',
                    'rps_limit': 'rps_limit',
                    'window_size': 'window_size',
                    'client_key': 'client_key',
                    'penalty_box_duration': 'penalty_box_duration',
                    'action': 'action',
                    'response_object_name': 'response_object_name',
                    'logger_type': 'logger_type',
                    'feature_revision': 'feature_revision',
                },
                'location_map': {
                    'rate_limiter_id': 'path',
                    'name': 'form',
                    'uri_dictionary_name': 'form',
                    'http_methods': 'form',
                    'rps_limit': 'form',
                    'window_size': 'form',
                    'client_key': 'form',
                    'penalty_box_duration': 'form',
                    'action': 'form',
                    'response_object_name': 'form',
                    'logger_type': 'form',
                    'feature_revision': 'form',
                },
                'path_params_allow_reserved_map': {
                },
                'collection_format_map': {
                    'http_methods': 'csv',
                    'client_key': 'csv',
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/x-www-form-urlencoded'
                ]
            },
            api_client=api_client
        )

    def create_rate_limiter(
        self,
        service_id,
        version_id,
        **kwargs
    ):
        """Create a rate limiter  # noqa: E501

        Create a rate limiter for a particular service and version.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_rate_limiter(service_id, version_id, async_req=True)
        >>> result = thread.get()

        Args:
            service_id (str): Alphanumeric string identifying the service.
            version_id (int): Integer identifying a service version.

        Keyword Args:
            name (str): A human readable name for the rate limiting rule.. [optional]
            uri_dictionary_name (str, none_type): The name of an Edge Dictionary containing URIs as keys. If not defined or `null`, all origin URIs will be rate limited.. [optional]
            http_methods ([str]): Array of HTTP methods to apply rate limiting to.. [optional]
            rps_limit (int): Upper limit of requests per second allowed by the rate limiter.. [optional]
            window_size (int): Number of seconds during which the RPS limit must be exceeded in order to trigger a violation.. [optional]
            client_key ([str]): Array of VCL variables used to generate a counter key to identify a client. Example variables include `req.http.Fastly-Client-IP`, `req.http.User-Agent`, or a custom header like `req.http.API-Key`.. [optional]
            penalty_box_duration (int): Length of time in minutes that the rate limiter is in effect after the initial violation is detected.. [optional]
            action (str): The action to take when a rate limiter violation is detected.. [optional]
            response_object_name (str, none_type): Name of existing response object. Required if `action` is `response_object`. Note that the rate limiter response is only updated to reflect the response object content when saving the rate limiter configuration.. [optional]
            logger_type (str): Name of the type of logging endpoint to be used when action is `log_only`. The logging endpoint type is used to determine the appropriate log format to use when emitting log entries.. [optional]
            feature_revision (int): Revision number of the rate limiting feature implementation. Defaults to the most recent revision.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            RateLimiterResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['service_id'] = \
            service_id
        kwargs['version_id'] = \
            version_id
        return self.create_rate_limiter_endpoint.call_with_http_info(**kwargs)

    def delete_rate_limiter(
        self,
        rate_limiter_id,
        **kwargs
    ):
        """Delete a rate limiter  # noqa: E501

        Delete a rate limiter by its ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_rate_limiter(rate_limiter_id, async_req=True)
        >>> result = thread.get()

        Args:
            rate_limiter_id (str): Alphanumeric string identifying the rate limiter.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            InlineResponse200
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['rate_limiter_id'] = \
            rate_limiter_id
        return self.delete_rate_limiter_endpoint.call_with_http_info(**kwargs)

    def get_rate_limiter(
        self,
        rate_limiter_id,
        **kwargs
    ):
        """Get a rate limiter  # noqa: E501

        Get a rate limiter by its ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_rate_limiter(rate_limiter_id, async_req=True)
        >>> result = thread.get()

        Args:
            rate_limiter_id (str): Alphanumeric string identifying the rate limiter.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            RateLimiterResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['rate_limiter_id'] = \
            rate_limiter_id
        return self.get_rate_limiter_endpoint.call_with_http_info(**kwargs)

    def list_rate_limiters(
        self,
        service_id,
        version_id,
        **kwargs
    ):
        """List rate limiters  # noqa: E501

        List all rate limiters for a particular service and version.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_rate_limiters(service_id, version_id, async_req=True)
        >>> result = thread.get()

        Args:
            service_id (str): Alphanumeric string identifying the service.
            version_id (int): Integer identifying a service version.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            [RateLimiterResponse]
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['service_id'] = \
            service_id
        kwargs['version_id'] = \
            version_id
        return self.list_rate_limiters_endpoint.call_with_http_info(**kwargs)

    def update_rate_limiter(
        self,
        rate_limiter_id,
        **kwargs
    ):
        """Update a rate limiter  # noqa: E501

        Update a rate limiter by its ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_rate_limiter(rate_limiter_id, async_req=True)
        >>> result = thread.get()

        Args:
            rate_limiter_id (str): Alphanumeric string identifying the rate limiter.

        Keyword Args:
            name (str): A human readable name for the rate limiting rule.. [optional]
            uri_dictionary_name (str, none_type): The name of an Edge Dictionary containing URIs as keys. If not defined or `null`, all origin URIs will be rate limited.. [optional]
            http_methods ([str]): Array of HTTP methods to apply rate limiting to.. [optional]
            rps_limit (int): Upper limit of requests per second allowed by the rate limiter.. [optional]
            window_size (int): Number of seconds during which the RPS limit must be exceeded in order to trigger a violation.. [optional]
            client_key ([str]): Array of VCL variables used to generate a counter key to identify a client. Example variables include `req.http.Fastly-Client-IP`, `req.http.User-Agent`, or a custom header like `req.http.API-Key`.. [optional]
            penalty_box_duration (int): Length of time in minutes that the rate limiter is in effect after the initial violation is detected.. [optional]
            action (str): The action to take when a rate limiter violation is detected.. [optional]
            response_object_name (str, none_type): Name of existing response object. Required if `action` is `response_object`. Note that the rate limiter response is only updated to reflect the response object content when saving the rate limiter configuration.. [optional]
            logger_type (str): Name of the type of logging endpoint to be used when action is `log_only`. The logging endpoint type is used to determine the appropriate log format to use when emitting log entries.. [optional]
            feature_revision (int): Revision number of the rate limiting feature implementation. Defaults to the most recent revision.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            RateLimiterResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['rate_limiter_id'] = \
            rate_limiter_id
        return self.update_rate_limiter_endpoint.call_with_http_info(**kwargs)




"""
    Fastly API

    Via the Fastly API you can perform any of the operations that are possible within the management console,  including creating services, domains, and backends, configuring rules or uploading your own application code, as well as account operations such as user administration and billing reports. The API is organized into collections of endpoints that allow manipulation of objects related to Fastly services and accounts. For the most accurate and up-to-date API reference content, visit our [Developer Hub](https://developer.fastly.com/reference/api/)   # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: oss@fastly.com
"""



class OpenApiException(Exception):
    """The base exception class for all OpenAPIExceptions"""


class ApiTypeError(OpenApiException, TypeError):
    def __init__(self, msg, path_to_item=None, valid_classes=None,
                 key_type=None):
        """ Raises an exception for TypeErrors

        Args:
            msg (str): the exception message

        Keyword Args:
            path_to_item (list): a list of keys an indices to get to the
                                 current_item
                                 None if unset
            valid_classes (tuple): the primitive classes that current item
                                   should be an instance of
                                   None if unset
            key_type (bool): False if our value is a value in a dict
                             True if it is a key in a dict
                             False if our item is an item in a list
                             None if unset
        """
        self.path_to_item = path_to_item
        self.valid_classes = valid_classes
        self.key_type = key_type
        full_msg = msg
        if path_to_item:
            full_msg = "{0} at {1}".format(msg, render_path(path_to_item))
        super(ApiTypeError, self).__init__(full_msg)


class ApiValueError(OpenApiException, ValueError):
    def __init__(self, msg, path_to_item=None):
        """
        Args:
            msg (str): the exception message

        Keyword Args:
            path_to_item (list) the path to the exception in the
                received_data dict. None if unset
        """

        self.path_to_item = path_to_item
        full_msg = msg
        if path_to_item:
            full_msg = "{0} at {1}".format(msg, render_path(path_to_item))
        super(ApiValueError, self).__init__(full_msg)


class ApiAttributeError(OpenApiException, AttributeError):
    def __init__(self, msg, path_to_item=None):
        """
        Raised when an attribute reference or assignment fails.

        Args:
            msg (str): the exception message

        Keyword Args:
            path_to_item (None/list) the path to the exception in the
                received_data dict
        """
        self.path_to_item = path_to_item
        full_msg = msg
        if path_to_item:
            full_msg = "{0} at {1}".format(msg, render_path(path_to_item))
        super(ApiAttributeError, self).__init__(full_msg)


class ApiKeyError(OpenApiException, KeyError):
    def __init__(self, msg, path_to_item=None):
        """
        Args:
            msg (str): the exception message

        Keyword Args:
            path_to_item (None/list) the path to the exception in the
                received_data dict
        """
        self.path_to_item = path_to_item
        full_msg = msg
        if path_to_item:
            full_msg = "{0} at {1}".format(msg, render_path(path_to_item))
        super(ApiKeyError, self).__init__(full_msg)


class ApiException(OpenApiException):

    def __init__(self, status=None, reason=None, http_resp=None):
        if http_resp:
            self.status = http_resp.status
            self.reason = http_resp.reason
            self.body = http_resp.data
            self.headers = http_resp.getheaders()
        else:
            self.status = status
            self.reason = reason
            self.body = None
            self.headers = None

    def __str__(self):
        """Custom error messages for exception"""
        error_message = "({0})\n"\
                        "Reason: {1}\n".format(self.status, self.reason)
        if self.headers:
            error_message += "HTTP response headers: {0}\n".format(
                self.headers)

        if self.body:
            error_message += "HTTP response body: {0}\n".format(self.body)

        return error_message


class NotFoundException(ApiException):

    def __init__(self, status=None, reason=None, http_resp=None):
        super(NotFoundException, self).__init__(status, reason, http_resp)


class UnauthorizedException(ApiException):

    def __init__(self, status=None, reason=None, http_resp=None):
        super(UnauthorizedException, self).__init__(status, reason, http_resp)


class ForbiddenException(ApiException):

    def __init__(self, status=None, reason=None, http_resp=None):
        super(ForbiddenException, self).__init__(status, reason, http_resp)


class ServiceException(ApiException):

    def __init__(self, status=None, reason=None, http_resp=None):
        super(ServiceException, self).__init__(status, reason, http_resp)


def render_path(path_to_item):
    """Returns a string representation of a path"""
    result = ""
    for pth in path_to_item:
        if isinstance(pth, int):
            result += "[{0}]".format(pth)
        else:
            result += "['{0}']".format(pth)
    return result



# flake8: noqa

# Import all models into this package.
# If you have many models here with many references from one model to another this may
# raise a RecursionError.
# To avoid this, import only the models that you directly need like:
# from from fastly.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from fastly.model.acl import Acl
from fastly.model.acl_entry import AclEntry
from fastly.model.acl_entry_response import AclEntryResponse
from fastly.model.acl_entry_response_all_of import AclEntryResponseAllOf
from fastly.model.acl_response import AclResponse
from fastly.model.acl_response_all_of import AclResponseAllOf
from fastly.model.apex_redirect import ApexRedirect
from fastly.model.apex_redirect_all_of import ApexRedirectAllOf
from fastly.model.automation_token import AutomationToken
from fastly.model.automation_token_create_request import AutomationTokenCreateRequest
from fastly.model.automation_token_create_request_attributes import AutomationTokenCreateRequestAttributes
from fastly.model.automation_token_create_response import AutomationTokenCreateResponse
from fastly.model.automation_token_create_response_all_of import AutomationTokenCreateResponseAllOf
from fastly.model.automation_token_error_response import AutomationTokenErrorResponse
from fastly.model.automation_token_response import AutomationTokenResponse
from fastly.model.automation_token_response_all_of import AutomationTokenResponseAllOf
from fastly.model.aws_region import AwsRegion
from fastly.model.backend import Backend
from fastly.model.backend_response import BackendResponse
from fastly.model.backend_response_all_of import BackendResponseAllOf
from fastly.model.batch import Batch
from fastly.model.batch_errors import BatchErrors
from fastly.model.billing import Billing
from fastly.model.billing_address_attributes import BillingAddressAttributes
from fastly.model.billing_address_request import BillingAddressRequest
from fastly.model.billing_address_request_data import BillingAddressRequestData
from fastly.model.billing_address_response import BillingAddressResponse
from fastly.model.billing_address_response_data import BillingAddressResponseData
from fastly.model.billing_address_verification_error_response import BillingAddressVerificationErrorResponse
from fastly.model.billing_address_verification_error_response_errors import BillingAddressVerificationErrorResponseErrors
from fastly.model.billing_estimate_lines import BillingEstimateLines
from fastly.model.billing_estimate_lines_line_items import BillingEstimateLinesLineItems
from fastly.model.billing_estimate_response import BillingEstimateResponse
from fastly.model.billing_response import BillingResponse
from fastly.model.billing_response_item_items_data import BillingResponseItemItemsData
from fastly.model.billing_response_line_item import BillingResponseLineItem
from fastly.model.billing_response_line_items import BillingResponseLineItems
from fastly.model.billing_status import BillingStatus
from fastly.model.billing_total import BillingTotal
from fastly.model.billing_total_extras import BillingTotalExtras
from fastly.model.bulk_update_acl_entries_request import BulkUpdateAclEntriesRequest
from fastly.model.bulk_update_acl_entry import BulkUpdateAclEntry
from fastly.model.bulk_update_acl_entry_all_of import BulkUpdateAclEntryAllOf
from fastly.model.bulk_update_config_store_item import BulkUpdateConfigStoreItem
from fastly.model.bulk_update_config_store_item_all_of import BulkUpdateConfigStoreItemAllOf
from fastly.model.bulk_update_config_store_list_request import BulkUpdateConfigStoreListRequest
from fastly.model.bulk_update_dictionary_item import BulkUpdateDictionaryItem
from fastly.model.bulk_update_dictionary_list_request import BulkUpdateDictionaryListRequest
from fastly.model.bulk_waf_active_rule import BulkWafActiveRule
from fastly.model.bulk_waf_active_rules import BulkWafActiveRules
from fastly.model.cache_setting import CacheSetting
from fastly.model.cache_setting_response import CacheSettingResponse
from fastly.model.client_key import ClientKey
from fastly.model.condition import Condition
from fastly.model.condition_response import ConditionResponse
from fastly.model.conditions_response import ConditionsResponse
from fastly.model.config_store import ConfigStore
from fastly.model.config_store_info_response import ConfigStoreInfoResponse
from fastly.model.config_store_item import ConfigStoreItem
from fastly.model.config_store_item_response import ConfigStoreItemResponse
from fastly.model.config_store_item_response_all_of import ConfigStoreItemResponseAllOf
from fastly.model.config_store_response import ConfigStoreResponse
from fastly.model.config_store_response_all_of import ConfigStoreResponseAllOf
from fastly.model.contact import Contact
from fastly.model.contact_response import ContactResponse
from fastly.model.contact_response_all_of import ContactResponseAllOf
from fastly.model.content import Content
from fastly.model.create_response_object_request import CreateResponseObjectRequest
from fastly.model.customer import Customer
from fastly.model.customer_response import CustomerResponse
from fastly.model.customer_response_all_of import CustomerResponseAllOf
from fastly.model.dictionary import Dictionary
from fastly.model.dictionary_info_response import DictionaryInfoResponse
from fastly.model.dictionary_item import DictionaryItem
from fastly.model.dictionary_item_response import DictionaryItemResponse
from fastly.model.dictionary_item_response_all_of import DictionaryItemResponseAllOf
from fastly.model.dictionary_response import DictionaryResponse
from fastly.model.dictionary_response_all_of import DictionaryResponseAllOf
from fastly.model.diff_response import DiffResponse
from fastly.model.director import Director
from fastly.model.director_backend import DirectorBackend
from fastly.model.director_backend_all_of import DirectorBackendAllOf
from fastly.model.director_response import DirectorResponse
from fastly.model.domain import Domain
from fastly.model.domain_check_response import DomainCheckResponse
from fastly.model.domain_check_response_list import DomainCheckResponseList
from fastly.model.domain_inspector import DomainInspector
from fastly.model.domain_inspector_entry import DomainInspectorEntry
from fastly.model.domain_inspector_entry_dimensions import DomainInspectorEntryDimensions
from fastly.model.domain_inspector_entry_values import DomainInspectorEntryValues
from fastly.model.domain_inspector_measurements import DomainInspectorMeasurements
from fastly.model.domain_inspector_realtime_entry import DomainInspectorRealtimeEntry
from fastly.model.domain_response import DomainResponse
from fastly.model.domains_response import DomainsResponse
from fastly.model.enabled_product_response import EnabledProductResponse
from fastly.model.enabled_product_response_links import EnabledProductResponseLinks
from fastly.model.enabled_product_response_product import EnabledProductResponseProduct
from fastly.model.enabled_product_response_service import EnabledProductResponseService
from fastly.model.error import Error
from fastly.model.error_response_data import ErrorResponseData
from fastly.model.event import Event
from fastly.model.event_attributes import EventAttributes
from fastly.model.event_data import EventData
from fastly.model.event_data_items import EventDataItems
from fastly.model.event_response import EventResponse
from fastly.model.events_response import EventsResponse
from fastly.model.generic_token_error import GenericTokenError
from fastly.model.gzip import Gzip
from fastly.model.gzip_response import GzipResponse
from fastly.model.header import Header
from fastly.model.header_response import HeaderResponse
from fastly.model.header_response_additional import HeaderResponseAdditional
from fastly.model.healthcheck import Healthcheck
from fastly.model.healthcheck_response import HealthcheckResponse
from fastly.model.historical import Historical
from fastly.model.historical_ddos import HistoricalDdos
from fastly.model.historical_ddos_meta import HistoricalDdosMeta
from fastly.model.historical_domains import HistoricalDomains
from fastly.model.historical_domains_data import HistoricalDomainsData
from fastly.model.historical_domains_meta import HistoricalDomainsMeta
from fastly.model.historical_domains_meta_filters import HistoricalDomainsMetaFilters
from fastly.model.historical_domains_response import HistoricalDomainsResponse
from fastly.model.historical_domains_response_all_of import HistoricalDomainsResponseAllOf
from fastly.model.historical_meta import HistoricalMeta
from fastly.model.historical_origins_response import HistoricalOriginsResponse
from fastly.model.historical_origins_response_all_of import HistoricalOriginsResponseAllOf
from fastly.model.historical_regions_response import HistoricalRegionsResponse
from fastly.model.historical_regions_response_all_of import HistoricalRegionsResponseAllOf
from fastly.model.historical_stats_aggregated_response import HistoricalStatsAggregatedResponse
from fastly.model.historical_stats_aggregated_response_all_of import HistoricalStatsAggregatedResponseAllOf
from fastly.model.historical_stats_by_service_response import HistoricalStatsByServiceResponse
from fastly.model.historical_stats_by_service_response_all_of import HistoricalStatsByServiceResponseAllOf
from fastly.model.historical_stats_data import HistoricalStatsData
from fastly.model.historical_usage_aggregated_response import HistoricalUsageAggregatedResponse
from fastly.model.historical_usage_aggregated_response_all_of import HistoricalUsageAggregatedResponseAllOf
from fastly.model.historical_usage_data import HistoricalUsageData
from fastly.model.historical_usage_month_response import HistoricalUsageMonthResponse
from fastly.model.historical_usage_month_response_all_of import HistoricalUsageMonthResponseAllOf
from fastly.model.historical_usage_month_response_data import HistoricalUsageMonthResponseData
from fastly.model.historical_usage_service import HistoricalUsageService
from fastly.model.historical_usage_service_response import HistoricalUsageServiceResponse
from fastly.model.historical_usage_service_response_all_of import HistoricalUsageServiceResponseAllOf
from fastly.model.http3 import Http3
from fastly.model.http3_all_of import Http3AllOf
from fastly.model.http_response_format import HttpResponseFormat
from fastly.model.http_stream_format import HttpStreamFormat
from fastly.model.iam_permission import IamPermission
from fastly.model.iam_role import IamRole
from fastly.model.iam_role_all_of import IamRoleAllOf
from fastly.model.iam_service_group import IamServiceGroup
from fastly.model.iam_service_group_all_of import IamServiceGroupAllOf
from fastly.model.iam_user_group import IamUserGroup
from fastly.model.iam_user_group_all_of import IamUserGroupAllOf
from fastly.model.included_with_waf_active_rule import IncludedWithWafActiveRule
from fastly.model.included_with_waf_active_rule_item import IncludedWithWafActiveRuleItem
from fastly.model.included_with_waf_exclusion import IncludedWithWafExclusion
from fastly.model.included_with_waf_exclusion_item import IncludedWithWafExclusionItem
from fastly.model.included_with_waf_firewall import IncludedWithWafFirewall
from fastly.model.included_with_waf_firewall_version import IncludedWithWafFirewallVersion
from fastly.model.included_with_waf_firewall_version_item import IncludedWithWafFirewallVersionItem
from fastly.model.included_with_waf_rule import IncludedWithWafRule
from fastly.model.included_with_waf_rule_item import IncludedWithWafRuleItem
from fastly.model.included_with_waf_rule_revision import IncludedWithWafRuleRevision
from fastly.model.inline_object import InlineObject
from fastly.model.inline_object1 import InlineObject1
from fastly.model.inline_response200 import InlineResponse200
from fastly.model.inline_response2001 import InlineResponse2001
from fastly.model.inline_response2002 import InlineResponse2002
from fastly.model.inline_response2003 import InlineResponse2003
from fastly.model.inline_response2003_meta import InlineResponse2003Meta
from fastly.model.inline_response2004 import InlineResponse2004
from fastly.model.inline_response2004_meta import InlineResponse2004Meta
from fastly.model.inline_response2005 import InlineResponse2005
from fastly.model.inline_response2006 import InlineResponse2006
from fastly.model.inline_response2007 import InlineResponse2007
from fastly.model.inline_response400 import InlineResponse400
from fastly.model.invitation import Invitation
from fastly.model.invitation_data import InvitationData
from fastly.model.invitation_data_attributes import InvitationDataAttributes
from fastly.model.invitation_response import InvitationResponse
from fastly.model.invitation_response_all_of import InvitationResponseAllOf
from fastly.model.invitation_response_data import InvitationResponseData
from fastly.model.invitation_response_data_all_of import InvitationResponseDataAllOf
from fastly.model.invitations_response import InvitationsResponse
from fastly.model.invitations_response_all_of import InvitationsResponseAllOf
from fastly.model.invoice import Invoice
from fastly.model.invoice_response import InvoiceResponse
from fastly.model.invoicelineitems import Invoicelineitems
from fastly.model.legacy_waf_configuration_set import LegacyWafConfigurationSet
from fastly.model.legacy_waf_firewall import LegacyWafFirewall
from fastly.model.legacy_waf_owasp import LegacyWafOwasp
from fastly.model.legacy_waf_rule import LegacyWafRule
from fastly.model.legacy_waf_rule_status import LegacyWafRuleStatus
from fastly.model.legacy_waf_ruleset import LegacyWafRuleset
from fastly.model.legacy_waf_tag import LegacyWafTag
from fastly.model.legacy_waf_update_status import LegacyWafUpdateStatus
from fastly.model.line_item_data import LineItemData
from fastly.model.line_item_data_read_only_invoice_id import LineItemDataReadOnlyInvoiceId
from fastly.model.list_invoices_response import ListInvoicesResponse
from fastly.model.listinvoices import Listinvoices
from fastly.model.logging_address_and_port import LoggingAddressAndPort
from fastly.model.logging_azureblob_additional import LoggingAzureblobAdditional
from fastly.model.logging_azureblob_response import LoggingAzureblobResponse
from fastly.model.logging_bigquery_additional import LoggingBigqueryAdditional
from fastly.model.logging_bigquery_response import LoggingBigqueryResponse
from fastly.model.logging_cloudfiles_additional import LoggingCloudfilesAdditional
from fastly.model.logging_cloudfiles_response import LoggingCloudfilesResponse
from fastly.model.logging_common import LoggingCommon
from fastly.model.logging_common_response import LoggingCommonResponse
from fastly.model.logging_common_response_all_of import LoggingCommonResponseAllOf
from fastly.model.logging_common_response_all_of1 import LoggingCommonResponseAllOf1
from fastly.model.logging_datadog_additional import LoggingDatadogAdditional
from fastly.model.logging_datadog_response import LoggingDatadogResponse
from fastly.model.logging_digitalocean_additional import LoggingDigitaloceanAdditional
from fastly.model.logging_digitalocean_response import LoggingDigitaloceanResponse
from fastly.model.logging_elasticsearch_additional import LoggingElasticsearchAdditional
from fastly.model.logging_elasticsearch_response import LoggingElasticsearchResponse
from fastly.model.logging_format_version_integer import LoggingFormatVersionInteger
from fastly.model.logging_format_version_string import LoggingFormatVersionString
from fastly.model.logging_ftp_additional import LoggingFtpAdditional
from fastly.model.logging_ftp_response import LoggingFtpResponse
from fastly.model.logging_ftp_response_all_of import LoggingFtpResponseAllOf
from fastly.model.logging_gcs_additional import LoggingGcsAdditional
from fastly.model.logging_gcs_common import LoggingGcsCommon
from fastly.model.logging_gcs_response import LoggingGcsResponse
from fastly.model.logging_generic_common import LoggingGenericCommon
from fastly.model.logging_generic_common_response import LoggingGenericCommonResponse
from fastly.model.logging_generic_common_response_all_of import LoggingGenericCommonResponseAllOf
from fastly.model.logging_generic_common_response_all_of1 import LoggingGenericCommonResponseAllOf1
from fastly.model.logging_google_pubsub_additional import LoggingGooglePubsubAdditional
from fastly.model.logging_google_pubsub_response import LoggingGooglePubsubResponse
from fastly.model.logging_heroku_additional import LoggingHerokuAdditional
from fastly.model.logging_heroku_response import LoggingHerokuResponse
from fastly.model.logging_honeycomb_additional import LoggingHoneycombAdditional
from fastly.model.logging_honeycomb_response import LoggingHoneycombResponse
from fastly.model.logging_https_additional import LoggingHttpsAdditional
from fastly.model.logging_https_response import LoggingHttpsResponse
from fastly.model.logging_kafka_additional import LoggingKafkaAdditional
from fastly.model.logging_kafka_response import LoggingKafkaResponse
from fastly.model.logging_kafka_response_post import LoggingKafkaResponsePost
from fastly.model.logging_kinesis_additional import LoggingKinesisAdditional
from fastly.model.logging_kinesis_response import LoggingKinesisResponse
from fastly.model.logging_logentries_additional import LoggingLogentriesAdditional
from fastly.model.logging_logentries_response import LoggingLogentriesResponse
from fastly.model.logging_loggly_additional import LoggingLogglyAdditional
from fastly.model.logging_loggly_response import LoggingLogglyResponse
from fastly.model.logging_logshuttle_additional import LoggingLogshuttleAdditional
from fastly.model.logging_logshuttle_response import LoggingLogshuttleResponse
from fastly.model.logging_message_type import LoggingMessageType
from fastly.model.logging_newrelic_additional import LoggingNewrelicAdditional
from fastly.model.logging_newrelic_response import LoggingNewrelicResponse
from fastly.model.logging_newrelicotlp_additional import LoggingNewrelicotlpAdditional
from fastly.model.logging_newrelicotlp_response import LoggingNewrelicotlpResponse
from fastly.model.logging_openstack_additional import LoggingOpenstackAdditional
from fastly.model.logging_openstack_response import LoggingOpenstackResponse
from fastly.model.logging_papertrail_response import LoggingPapertrailResponse
from fastly.model.logging_placement import LoggingPlacement
from fastly.model.logging_request_caps_common import LoggingRequestCapsCommon
from fastly.model.logging_s3_additional import LoggingS3Additional
from fastly.model.logging_s3_response import LoggingS3Response
from fastly.model.logging_scalyr_additional import LoggingScalyrAdditional
from fastly.model.logging_scalyr_response import LoggingScalyrResponse
from fastly.model.logging_sftp_additional import LoggingSftpAdditional
from fastly.model.logging_sftp_response import LoggingSftpResponse
from fastly.model.logging_sftp_response_all_of import LoggingSftpResponseAllOf
from fastly.model.logging_splunk_additional import LoggingSplunkAdditional
from fastly.model.logging_splunk_response import LoggingSplunkResponse
from fastly.model.logging_sumologic_additional import LoggingSumologicAdditional
from fastly.model.logging_sumologic_response import LoggingSumologicResponse
from fastly.model.logging_syslog_additional import LoggingSyslogAdditional
from fastly.model.logging_syslog_response import LoggingSyslogResponse
from fastly.model.logging_tls_common import LoggingTlsCommon
from fastly.model.logging_use_tls import LoggingUseTls
from fastly.model.metadata import Metadata
from fastly.model.mutual_authentication import MutualAuthentication
from fastly.model.mutual_authentication_data import MutualAuthenticationData
from fastly.model.mutual_authentication_data_attributes import MutualAuthenticationDataAttributes
from fastly.model.mutual_authentication_response import MutualAuthenticationResponse
from fastly.model.mutual_authentication_response_attributes import MutualAuthenticationResponseAttributes
from fastly.model.mutual_authentication_response_attributes_all_of import MutualAuthenticationResponseAttributesAllOf
from fastly.model.mutual_authentication_response_data import MutualAuthenticationResponseData
from fastly.model.mutual_authentication_response_data_all_of import MutualAuthenticationResponseDataAllOf
from fastly.model.mutual_authentications_response import MutualAuthenticationsResponse
from fastly.model.mutual_authentications_response_all_of import MutualAuthenticationsResponseAllOf
from fastly.model.number_version import NumberVersion
from fastly.model.origin_inspector import OriginInspector
from fastly.model.origin_inspector_dimensions import OriginInspectorDimensions
from fastly.model.origin_inspector_entry import OriginInspectorEntry
from fastly.model.origin_inspector_entry_values import OriginInspectorEntryValues
from fastly.model.origin_inspector_historical import OriginInspectorHistorical
from fastly.model.origin_inspector_historical_data import OriginInspectorHistoricalData
from fastly.model.origin_inspector_historical_meta import OriginInspectorHistoricalMeta
from fastly.model.origin_inspector_historical_meta_filters import OriginInspectorHistoricalMetaFilters
from fastly.model.origin_inspector_measurements import OriginInspectorMeasurements
from fastly.model.origin_inspector_realtime_entry import OriginInspectorRealtimeEntry
from fastly.model.origin_inspector_realtime_entry_recorded import OriginInspectorRealtimeEntryRecorded
from fastly.model.origin_inspector_subsequent_request_timestamp import OriginInspectorSubsequentRequestTimestamp
from fastly.model.origin_inspector_values import OriginInspectorValues
from fastly.model.package import Package
from fastly.model.package_metadata import PackageMetadata
from fastly.model.package_response import PackageResponse
from fastly.model.package_response_all_of import PackageResponseAllOf
from fastly.model.pagination import Pagination
from fastly.model.pagination_cursor_meta import PaginationCursorMeta
from fastly.model.pagination_links import PaginationLinks
from fastly.model.pagination_meta import PaginationMeta
from fastly.model.permission import Permission
from fastly.model.platform_ddos_data_items import PlatformDdosDataItems
from fastly.model.platform_ddos_entry import PlatformDdosEntry
from fastly.model.platform_ddos_response import PlatformDdosResponse
from fastly.model.platform_ddos_response_all_of import PlatformDdosResponseAllOf
from fastly.model.platform_ddos_response_data import PlatformDdosResponseData
from fastly.model.pool_additional import PoolAdditional
from fastly.model.pool_response import PoolResponse
from fastly.model.pool_response_all_of import PoolResponseAllOf
from fastly.model.pool_response_common import PoolResponseCommon
from fastly.model.pool_response_post import PoolResponsePost
from fastly.model.pool_response_post_all_of import PoolResponsePostAllOf
from fastly.model.pop import Pop
from fastly.model.pop_coordinates import PopCoordinates
from fastly.model.public_ip_list import PublicIpList
from fastly.model.publish_item import PublishItem
from fastly.model.publish_item_formats import PublishItemFormats
from fastly.model.publish_request import PublishRequest
from fastly.model.purge_keys import PurgeKeys
from fastly.model.purge_keys_response import PurgeKeysResponse
from fastly.model.purge_response import PurgeResponse
from fastly.model.rate_limiter import RateLimiter
from fastly.model.rate_limiter_response import RateLimiterResponse
from fastly.model.rate_limiter_response_all_of import RateLimiterResponseAllOf
from fastly.model.read_only_customer_id import ReadOnlyCustomerId
from fastly.model.read_only_id import ReadOnlyId
from fastly.model.read_only_service_id import ReadOnlyServiceId
from fastly.model.read_only_user_id import ReadOnlyUserId
from fastly.model.read_only_version import ReadOnlyVersion
from fastly.model.realtime import Realtime
from fastly.model.realtime_entry import RealtimeEntry
from fastly.model.realtime_entry_aggregated import RealtimeEntryAggregated
from fastly.model.realtime_entry_datacenter import RealtimeEntryDatacenter
from fastly.model.realtime_entry_recorded import RealtimeEntryRecorded
from fastly.model.realtime_measurements import RealtimeMeasurements
from fastly.model.recorded_timestamp import RecordedTimestamp
from fastly.model.relationship_common_name import RelationshipCommonName
from fastly.model.relationship_customer import RelationshipCustomer
from fastly.model.relationship_customer_customer import RelationshipCustomerCustomer
from fastly.model.relationship_member_customer import RelationshipMemberCustomer
from fastly.model.relationship_member_mutual_authentication import RelationshipMemberMutualAuthentication
from fastly.model.relationship_member_service import RelationshipMemberService
from fastly.model.relationship_member_service_invitation import RelationshipMemberServiceInvitation
from fastly.model.relationship_member_tls_activation import RelationshipMemberTlsActivation
from fastly.model.relationship_member_tls_bulk_certificate import RelationshipMemberTlsBulkCertificate
from fastly.model.relationship_member_tls_certificate import RelationshipMemberTlsCertificate
from fastly.model.relationship_member_tls_configuration import RelationshipMemberTlsConfiguration
from fastly.model.relationship_member_tls_dns_record import RelationshipMemberTlsDnsRecord
from fastly.model.relationship_member_tls_domain import RelationshipMemberTlsDomain
from fastly.model.relationship_member_tls_private_key import RelationshipMemberTlsPrivateKey
from fastly.model.relationship_member_tls_subscription import RelationshipMemberTlsSubscription
from fastly.model.relationship_member_waf_active_rule import RelationshipMemberWafActiveRule
from fastly.model.relationship_member_waf_firewall import RelationshipMemberWafFirewall
from fastly.model.relationship_member_waf_firewall_version import RelationshipMemberWafFirewallVersion
from fastly.model.relationship_member_waf_rule import RelationshipMemberWafRule
from fastly.model.relationship_member_waf_rule_revision import RelationshipMemberWafRuleRevision
from fastly.model.relationship_member_waf_tag import RelationshipMemberWafTag
from fastly.model.relationship_mutual_authentication import RelationshipMutualAuthentication
from fastly.model.relationship_mutual_authentication_mutual_authentication import RelationshipMutualAuthenticationMutualAuthentication
from fastly.model.relationship_mutual_authentications import RelationshipMutualAuthentications
from fastly.model.relationship_mutual_authentications_mutual_authentications import RelationshipMutualAuthenticationsMutualAuthentications
from fastly.model.relationship_service import RelationshipService
from fastly.model.relationship_service_invitations import RelationshipServiceInvitations
from fastly.model.relationship_service_invitations_create import RelationshipServiceInvitationsCreate
from fastly.model.relationship_service_invitations_create_service_invitations import RelationshipServiceInvitationsCreateServiceInvitations
from fastly.model.relationship_service_invitations_service_invitations import RelationshipServiceInvitationsServiceInvitations
from fastly.model.relationship_services import RelationshipServices
from fastly.model.relationship_services_services import RelationshipServicesServices
from fastly.model.relationship_tls_activation import RelationshipTlsActivation
from fastly.model.relationship_tls_activation_tls_activation import RelationshipTlsActivationTlsActivation
from fastly.model.relationship_tls_activations import RelationshipTlsActivations
from fastly.model.relationship_tls_bulk_certificate import RelationshipTlsBulkCertificate
from fastly.model.relationship_tls_bulk_certificate_tls_bulk_certificate import RelationshipTlsBulkCertificateTlsBulkCertificate
from fastly.model.relationship_tls_bulk_certificates import RelationshipTlsBulkCertificates
from fastly.model.relationship_tls_certificate import RelationshipTlsCertificate
from fastly.model.relationship_tls_certificate_tls_certificate import RelationshipTlsCertificateTlsCertificate
from fastly.model.relationship_tls_certificates import RelationshipTlsCertificates
from fastly.model.relationship_tls_certificates_tls_certificates import RelationshipTlsCertificatesTlsCertificates
from fastly.model.relationship_tls_configuration import RelationshipTlsConfiguration
from fastly.model.relationship_tls_configuration_for_tls_subscription import RelationshipTlsConfigurationForTlsSubscription
from fastly.model.relationship_tls_configuration_tls_configuration import RelationshipTlsConfigurationTlsConfiguration
from fastly.model.relationship_tls_configurations import RelationshipTlsConfigurations
from fastly.model.relationship_tls_configurations_tls_configurations import RelationshipTlsConfigurationsTlsConfigurations
from fastly.model.relationship_tls_dns_record import RelationshipTlsDnsRecord
from fastly.model.relationship_tls_dns_record_dns_record import RelationshipTlsDnsRecordDnsRecord
from fastly.model.relationship_tls_dns_records import RelationshipTlsDnsRecords
from fastly.model.relationship_tls_domain import RelationshipTlsDomain
from fastly.model.relationship_tls_domain_tls_domain import RelationshipTlsDomainTlsDomain
from fastly.model.relationship_tls_domains import RelationshipTlsDomains
from fastly.model.relationship_tls_domains_tls_domains import RelationshipTlsDomainsTlsDomains
from fastly.model.relationship_tls_private_key import RelationshipTlsPrivateKey
from fastly.model.relationship_tls_private_key_tls_private_key import RelationshipTlsPrivateKeyTlsPrivateKey
from fastly.model.relationship_tls_private_keys import RelationshipTlsPrivateKeys
from fastly.model.relationship_tls_private_keys_tls_private_keys import RelationshipTlsPrivateKeysTlsPrivateKeys
from fastly.model.relationship_tls_subscription import RelationshipTlsSubscription
from fastly.model.relationship_tls_subscription_tls_subscription import RelationshipTlsSubscriptionTlsSubscription
from fastly.model.relationship_tls_subscriptions import RelationshipTlsSubscriptions
from fastly.model.relationship_user import RelationshipUser
from fastly.model.relationship_user_user import RelationshipUserUser
from fastly.model.relationship_waf_active_rules import RelationshipWafActiveRules
from fastly.model.relationship_waf_active_rules_waf_active_rules import RelationshipWafActiveRulesWafActiveRules
from fastly.model.relationship_waf_firewall import RelationshipWafFirewall
from fastly.model.relationship_waf_firewall_version import RelationshipWafFirewallVersion
from fastly.model.relationship_waf_firewall_version_waf_firewall_version import RelationshipWafFirewallVersionWafFirewallVersion
from fastly.model.relationship_waf_firewall_versions import RelationshipWafFirewallVersions
from fastly.model.relationship_waf_firewall_waf_firewall import RelationshipWafFirewallWafFirewall
from fastly.model.relationship_waf_rule import RelationshipWafRule
from fastly.model.relationship_waf_rule_revision import RelationshipWafRuleRevision
from fastly.model.relationship_waf_rule_revision_waf_rule_revisions import RelationshipWafRuleRevisionWafRuleRevisions
from fastly.model.relationship_waf_rule_revisions import RelationshipWafRuleRevisions
from fastly.model.relationship_waf_rule_waf_rule import RelationshipWafRuleWafRule
from fastly.model.relationship_waf_rules import RelationshipWafRules
from fastly.model.relationship_waf_tags import RelationshipWafTags
from fastly.model.relationship_waf_tags_waf_tags import RelationshipWafTagsWafTags
from fastly.model.relationships_for_invitation import RelationshipsForInvitation
from fastly.model.relationships_for_mutual_authentication import RelationshipsForMutualAuthentication
from fastly.model.relationships_for_star import RelationshipsForStar
from fastly.model.relationships_for_tls_activation import RelationshipsForTlsActivation
from fastly.model.relationships_for_tls_bulk_certificate import RelationshipsForTlsBulkCertificate
from fastly.model.relationships_for_tls_configuration import RelationshipsForTlsConfiguration
from fastly.model.relationships_for_tls_domain import RelationshipsForTlsDomain
from fastly.model.relationships_for_tls_private_key import RelationshipsForTlsPrivateKey
from fastly.model.relationships_for_tls_subscription import RelationshipsForTlsSubscription
from fastly.model.relationships_for_waf_active_rule import RelationshipsForWafActiveRule
from fastly.model.relationships_for_waf_exclusion import RelationshipsForWafExclusion
from fastly.model.relationships_for_waf_firewall_version import RelationshipsForWafFirewallVersion
from fastly.model.relationships_for_waf_rule import RelationshipsForWafRule
from fastly.model.request_settings_additional import RequestSettingsAdditional
from fastly.model.request_settings_response import RequestSettingsResponse
from fastly.model.request_settings_response_all_of import RequestSettingsResponseAllOf
from fastly.model.resource import Resource
from fastly.model.resource_response import ResourceResponse
from fastly.model.resource_response_all_of import ResourceResponseAllOf
from fastly.model.response_object import ResponseObject
from fastly.model.response_object_response import ResponseObjectResponse
from fastly.model.results import Results
from fastly.model.role_user import RoleUser
from fastly.model.schemas_contact_response import SchemasContactResponse
from fastly.model.schemas_snippet_response import SchemasSnippetResponse
from fastly.model.schemas_snippet_response_common import SchemasSnippetResponseCommon
from fastly.model.schemas_user_response import SchemasUserResponse
from fastly.model.schemas_user_response_read_only import SchemasUserResponseReadOnly
from fastly.model.schemas_vcl_response import SchemasVclResponse
from fastly.model.schemas_version import SchemasVersion
from fastly.model.schemas_version_response import SchemasVersionResponse
from fastly.model.schemas_waf_firewall_version import SchemasWafFirewallVersion
from fastly.model.schemas_waf_firewall_version_data import SchemasWafFirewallVersionData
from fastly.model.secret import Secret
from fastly.model.secret_response import SecretResponse
from fastly.model.secret_store import SecretStore
from fastly.model.secret_store_response import SecretStoreResponse
from fastly.model.server import Server
from fastly.model.server_response import ServerResponse
from fastly.model.server_response_all_of import ServerResponseAllOf
from fastly.model.service import Service
from fastly.model.service_authorization import ServiceAuthorization
from fastly.model.service_authorization_data import ServiceAuthorizationData
from fastly.model.service_authorization_data_attributes import ServiceAuthorizationDataAttributes
from fastly.model.service_authorization_data_relationships import ServiceAuthorizationDataRelationships
from fastly.model.service_authorization_data_relationships_user import ServiceAuthorizationDataRelationshipsUser
from fastly.model.service_authorization_data_relationships_user_data import ServiceAuthorizationDataRelationshipsUserData
from fastly.model.service_authorization_response import ServiceAuthorizationResponse
from fastly.model.service_authorization_response_data import ServiceAuthorizationResponseData
from fastly.model.service_authorization_response_data_all_of import ServiceAuthorizationResponseDataAllOf
from fastly.model.service_authorizations_response import ServiceAuthorizationsResponse
from fastly.model.service_authorizations_response_all_of import ServiceAuthorizationsResponseAllOf
from fastly.model.service_create import ServiceCreate
from fastly.model.service_create_all_of import ServiceCreateAllOf
from fastly.model.service_detail import ServiceDetail
from fastly.model.service_detail_all_of import ServiceDetailAllOf
from fastly.model.service_id_and_version import ServiceIdAndVersion
from fastly.model.service_id_and_version_string import ServiceIdAndVersionString
from fastly.model.service_invitation import ServiceInvitation
from fastly.model.service_invitation_data import ServiceInvitationData
from fastly.model.service_invitation_data_attributes import ServiceInvitationDataAttributes
from fastly.model.service_invitation_data_relationships import ServiceInvitationDataRelationships
from fastly.model.service_invitation_response import ServiceInvitationResponse
from fastly.model.service_invitation_response_all_of import ServiceInvitationResponseAllOf
from fastly.model.service_invitation_response_all_of_data import ServiceInvitationResponseAllOfData
from fastly.model.service_list_response import ServiceListResponse
from fastly.model.service_list_response_all_of import ServiceListResponseAllOf
from fastly.model.service_response import ServiceResponse
from fastly.model.service_response_all_of import ServiceResponseAllOf
from fastly.model.service_version_detail import ServiceVersionDetail
from fastly.model.service_version_detail_or_null import ServiceVersionDetailOrNull
from fastly.model.settings import Settings
from fastly.model.settings_response import SettingsResponse
from fastly.model.signing_key import SigningKey
from fastly.model.snippet import Snippet
from fastly.model.snippet_all_of import SnippetAllOf
from fastly.model.snippet_common import SnippetCommon
from fastly.model.snippet_response import SnippetResponse
from fastly.model.snippet_response_common import SnippetResponseCommon
from fastly.model.snippet_response_common_all_of import SnippetResponseCommonAllOf
from fastly.model.snippet_response_post import SnippetResponsePost
from fastly.model.snippet_with_dynamic_number import SnippetWithDynamicNumber
from fastly.model.snippet_with_dynamic_number_all_of import SnippetWithDynamicNumberAllOf
from fastly.model.star import Star
from fastly.model.star_data import StarData
from fastly.model.star_response import StarResponse
from fastly.model.star_response_all_of import StarResponseAllOf
from fastly.model.stats import Stats
from fastly.model.store import Store
from fastly.model.store_response import StoreResponse
from fastly.model.subsequent_request_timestamp import SubsequentRequestTimestamp
from fastly.model.sudo_generic_token_error import SudoGenericTokenError
from fastly.model.sudo_request import SudoRequest
from fastly.model.sudo_response import SudoResponse
from fastly.model.timestamps import Timestamps
from fastly.model.timestamps_no_delete import TimestampsNoDelete
from fastly.model.tls_activation import TlsActivation
from fastly.model.tls_activation_data import TlsActivationData
from fastly.model.tls_activation_response import TlsActivationResponse
from fastly.model.tls_activation_response_data import TlsActivationResponseData
from fastly.model.tls_activation_response_data_all_of import TlsActivationResponseDataAllOf
from fastly.model.tls_activations_response import TlsActivationsResponse
from fastly.model.tls_activations_response_all_of import TlsActivationsResponseAllOf
from fastly.model.tls_bulk_certificate import TlsBulkCertificate
from fastly.model.tls_bulk_certificate_data import TlsBulkCertificateData
from fastly.model.tls_bulk_certificate_data_attributes import TlsBulkCertificateDataAttributes
from fastly.model.tls_bulk_certificate_response import TlsBulkCertificateResponse
from fastly.model.tls_bulk_certificate_response_attributes import TlsBulkCertificateResponseAttributes
from fastly.model.tls_bulk_certificate_response_attributes_all_of import TlsBulkCertificateResponseAttributesAllOf
from fastly.model.tls_bulk_certificate_response_data import TlsBulkCertificateResponseData
from fastly.model.tls_bulk_certificate_response_data_all_of import TlsBulkCertificateResponseDataAllOf
from fastly.model.tls_bulk_certificates_response import TlsBulkCertificatesResponse
from fastly.model.tls_bulk_certificates_response_all_of import TlsBulkCertificatesResponseAllOf
from fastly.model.tls_certificate import TlsCertificate
from fastly.model.tls_certificate_data import TlsCertificateData
from fastly.model.tls_certificate_data_attributes import TlsCertificateDataAttributes
from fastly.model.tls_certificate_response import TlsCertificateResponse
from fastly.model.tls_certificate_response_attributes import TlsCertificateResponseAttributes
from fastly.model.tls_certificate_response_attributes_all_of import TlsCertificateResponseAttributesAllOf
from fastly.model.tls_certificate_response_data import TlsCertificateResponseData
from fastly.model.tls_certificate_response_data_all_of import TlsCertificateResponseDataAllOf
from fastly.model.tls_certificates_response import TlsCertificatesResponse
from fastly.model.tls_certificates_response_all_of import TlsCertificatesResponseAllOf
from fastly.model.tls_common_response import TlsCommonResponse
from fastly.model.tls_common_response_all_of import TlsCommonResponseAllOf
from fastly.model.tls_common_response_all_of1 import TlsCommonResponseAllOf1
from fastly.model.tls_configuration import TlsConfiguration
from fastly.model.tls_configuration_data import TlsConfigurationData
from fastly.model.tls_configuration_data_attributes import TlsConfigurationDataAttributes
from fastly.model.tls_configuration_response import TlsConfigurationResponse
from fastly.model.tls_configuration_response_attributes import TlsConfigurationResponseAttributes
from fastly.model.tls_configuration_response_attributes_all_of import TlsConfigurationResponseAttributesAllOf
from fastly.model.tls_configuration_response_data import TlsConfigurationResponseData
from fastly.model.tls_configuration_response_data_all_of import TlsConfigurationResponseDataAllOf
from fastly.model.tls_configurations_response import TlsConfigurationsResponse
from fastly.model.tls_configurations_response_all_of import TlsConfigurationsResponseAllOf
from fastly.model.tls_csr import TlsCsr
from fastly.model.tls_csr_data import TlsCsrData
from fastly.model.tls_csr_data_attributes import TlsCsrDataAttributes
from fastly.model.tls_csr_error_response import TlsCsrErrorResponse
from fastly.model.tls_csr_response import TlsCsrResponse
from fastly.model.tls_csr_response_attributes import TlsCsrResponseAttributes
from fastly.model.tls_csr_response_data import TlsCsrResponseData
from fastly.model.tls_dns_record import TlsDnsRecord
from fastly.model.tls_domain_data import TlsDomainData
from fastly.model.tls_domains_response import TlsDomainsResponse
from fastly.model.tls_domains_response_all_of import TlsDomainsResponseAllOf
from fastly.model.tls_private_key import TlsPrivateKey
from fastly.model.tls_private_key_data import TlsPrivateKeyData
from fastly.model.tls_private_key_data_attributes import TlsPrivateKeyDataAttributes
from fastly.model.tls_private_key_response import TlsPrivateKeyResponse
from fastly.model.tls_private_key_response_attributes import TlsPrivateKeyResponseAttributes
from fastly.model.tls_private_key_response_attributes_all_of import TlsPrivateKeyResponseAttributesAllOf
from fastly.model.tls_private_key_response_data import TlsPrivateKeyResponseData
from fastly.model.tls_private_keys_response import TlsPrivateKeysResponse
from fastly.model.tls_private_keys_response_all_of import TlsPrivateKeysResponseAllOf
from fastly.model.tls_subscription import TlsSubscription
from fastly.model.tls_subscription_data import TlsSubscriptionData
from fastly.model.tls_subscription_data_attributes import TlsSubscriptionDataAttributes
from fastly.model.tls_subscription_response import TlsSubscriptionResponse
from fastly.model.tls_subscription_response_attributes import TlsSubscriptionResponseAttributes
from fastly.model.tls_subscription_response_attributes_all_of import TlsSubscriptionResponseAttributesAllOf
from fastly.model.tls_subscription_response_data import TlsSubscriptionResponseData
from fastly.model.tls_subscriptions_response import TlsSubscriptionsResponse
from fastly.model.tls_subscriptions_response_all_of import TlsSubscriptionsResponseAllOf
from fastly.model.token import Token
from fastly.model.token_created_response import TokenCreatedResponse
from fastly.model.token_created_response_all_of import TokenCreatedResponseAllOf
from fastly.model.token_response import TokenResponse
from fastly.model.token_response_all_of import TokenResponseAllOf
from fastly.model.tokens_additional_props import TokensAdditionalProps
from fastly.model.tokens_data import TokensData
from fastly.model.type_billing_address import TypeBillingAddress
from fastly.model.type_contact import TypeContact
from fastly.model.type_customer import TypeCustomer
from fastly.model.type_event import TypeEvent
from fastly.model.type_invitation import TypeInvitation
from fastly.model.type_mutual_authentication import TypeMutualAuthentication
from fastly.model.type_resource import TypeResource
from fastly.model.type_service import TypeService
from fastly.model.type_service_authorization import TypeServiceAuthorization
from fastly.model.type_service_invitation import TypeServiceInvitation
from fastly.model.type_star import TypeStar
from fastly.model.type_tls_activation import TypeTlsActivation
from fastly.model.type_tls_bulk_certificate import TypeTlsBulkCertificate
from fastly.model.type_tls_certificate import TypeTlsCertificate
from fastly.model.type_tls_configuration import TypeTlsConfiguration
from fastly.model.type_tls_csr import TypeTlsCsr
from fastly.model.type_tls_dns_record import TypeTlsDnsRecord
from fastly.model.type_tls_domain import TypeTlsDomain
from fastly.model.type_tls_private_key import TypeTlsPrivateKey
from fastly.model.type_tls_subscription import TypeTlsSubscription
from fastly.model.type_user import TypeUser
from fastly.model.type_waf_active_rule import TypeWafActiveRule
from fastly.model.type_waf_exclusion import TypeWafExclusion
from fastly.model.type_waf_firewall import TypeWafFirewall
from fastly.model.type_waf_firewall_version import TypeWafFirewallVersion
from fastly.model.type_waf_rule import TypeWafRule
from fastly.model.type_waf_rule_revision import TypeWafRuleRevision
from fastly.model.type_waf_tag import TypeWafTag
from fastly.model.update_billing_address_request import UpdateBillingAddressRequest
from fastly.model.update_billing_address_request_data import UpdateBillingAddressRequestData
from fastly.model.user import User
from fastly.model.user_response import UserResponse
from fastly.model.user_response_read_only import UserResponseReadOnly
from fastly.model.validator_result import ValidatorResult
from fastly.model.validator_result_data import ValidatorResultData
from fastly.model.validator_result_data_attributes import ValidatorResultDataAttributes
from fastly.model.validator_result_data_attributes_messages import ValidatorResultDataAttributesMessages
from fastly.model.values import Values
from fastly.model.values_ddos import ValuesDdos
from fastly.model.vcl import Vcl
from fastly.model.vcl_diff import VclDiff
from fastly.model.vcl_response import VclResponse
from fastly.model.vcl_syntax_highlighting_response import VclSyntaxHighlightingResponse
from fastly.model.version import Version
from fastly.model.version_create_response import VersionCreateResponse
from fastly.model.version_detail import VersionDetail
from fastly.model.version_detail_settings import VersionDetailSettings
from fastly.model.version_response import VersionResponse
from fastly.model.version_response_all_of import VersionResponseAllOf
from fastly.model.waf_active_rule import WafActiveRule
from fastly.model.waf_active_rule_creation_response import WafActiveRuleCreationResponse
from fastly.model.waf_active_rule_data import WafActiveRuleData
from fastly.model.waf_active_rule_data_attributes import WafActiveRuleDataAttributes
from fastly.model.waf_active_rule_response import WafActiveRuleResponse
from fastly.model.waf_active_rule_response_data import WafActiveRuleResponseData
from fastly.model.waf_active_rule_response_data_all_of import WafActiveRuleResponseDataAllOf
from fastly.model.waf_active_rule_response_data_attributes import WafActiveRuleResponseDataAttributes
from fastly.model.waf_active_rule_response_data_attributes_all_of import WafActiveRuleResponseDataAttributesAllOf
from fastly.model.waf_active_rule_response_data_relationships import WafActiveRuleResponseDataRelationships
from fastly.model.waf_active_rules_response import WafActiveRulesResponse
from fastly.model.waf_active_rules_response_all_of import WafActiveRulesResponseAllOf
from fastly.model.waf_exclusion import WafExclusion
from fastly.model.waf_exclusion_data import WafExclusionData
from fastly.model.waf_exclusion_data_attributes import WafExclusionDataAttributes
from fastly.model.waf_exclusion_response import WafExclusionResponse
from fastly.model.waf_exclusion_response_data import WafExclusionResponseData
from fastly.model.waf_exclusion_response_data_all_of import WafExclusionResponseDataAllOf
from fastly.model.waf_exclusion_response_data_attributes import WafExclusionResponseDataAttributes
from fastly.model.waf_exclusion_response_data_attributes_all_of import WafExclusionResponseDataAttributesAllOf
from fastly.model.waf_exclusion_response_data_relationships import WafExclusionResponseDataRelationships
from fastly.model.waf_exclusions_response import WafExclusionsResponse
from fastly.model.waf_exclusions_response_all_of import WafExclusionsResponseAllOf
from fastly.model.waf_firewall import WafFirewall
from fastly.model.waf_firewall_data import WafFirewallData
from fastly.model.waf_firewall_data_attributes import WafFirewallDataAttributes
from fastly.model.waf_firewall_response import WafFirewallResponse
from fastly.model.waf_firewall_response_data import WafFirewallResponseData
from fastly.model.waf_firewall_response_data_all_of import WafFirewallResponseDataAllOf
from fastly.model.waf_firewall_response_data_attributes import WafFirewallResponseDataAttributes
from fastly.model.waf_firewall_response_data_attributes_all_of import WafFirewallResponseDataAttributesAllOf
from fastly.model.waf_firewall_version import WafFirewallVersion
from fastly.model.waf_firewall_version_data import WafFirewallVersionData
from fastly.model.waf_firewall_version_data_attributes import WafFirewallVersionDataAttributes
from fastly.model.waf_firewall_version_response import WafFirewallVersionResponse
from fastly.model.waf_firewall_version_response_data import WafFirewallVersionResponseData
from fastly.model.waf_firewall_version_response_data_all_of import WafFirewallVersionResponseDataAllOf
from fastly.model.waf_firewall_version_response_data_attributes import WafFirewallVersionResponseDataAttributes
from fastly.model.waf_firewall_version_response_data_attributes_all_of import WafFirewallVersionResponseDataAttributesAllOf
from fastly.model.waf_firewall_versions_response import WafFirewallVersionsResponse
from fastly.model.waf_firewall_versions_response_all_of import WafFirewallVersionsResponseAllOf
from fastly.model.waf_firewalls_response import WafFirewallsResponse
from fastly.model.waf_firewalls_response_all_of import WafFirewallsResponseAllOf
from fastly.model.waf_rule import WafRule
from fastly.model.waf_rule_attributes import WafRuleAttributes
from fastly.model.waf_rule_response import WafRuleResponse
from fastly.model.waf_rule_response_data import WafRuleResponseData
from fastly.model.waf_rule_response_data_all_of import WafRuleResponseDataAllOf
from fastly.model.waf_rule_revision import WafRuleRevision
from fastly.model.waf_rule_revision_attributes import WafRuleRevisionAttributes
from fastly.model.waf_rule_revision_or_latest import WafRuleRevisionOrLatest
from fastly.model.waf_rule_revision_response import WafRuleRevisionResponse
from fastly.model.waf_rule_revision_response_data import WafRuleRevisionResponseData
from fastly.model.waf_rule_revision_response_data_all_of import WafRuleRevisionResponseDataAllOf
from fastly.model.waf_rule_revisions_response import WafRuleRevisionsResponse
from fastly.model.waf_rule_revisions_response_all_of import WafRuleRevisionsResponseAllOf
from fastly.model.waf_rules_response import WafRulesResponse
from fastly.model.waf_rules_response_all_of import WafRulesResponseAllOf
from fastly.model.waf_tag import WafTag
from fastly.model.waf_tag_attributes import WafTagAttributes
from fastly.model.waf_tags_response import WafTagsResponse
from fastly.model.waf_tags_response_all_of import WafTagsResponseAllOf
from fastly.model.waf_tags_response_data_item import WafTagsResponseDataItem
from fastly.model.ws_message_format import WsMessageFormat



# We can not import model classes here because that would create a circular
# reference which would not work in python2.
# Do not import all models into this module because that uses a lot of memory and stack frames.
# If you need the ability to import all models from one package, import them with
# from {{packageName}.models import ModelA, ModelB
